with Glib; use Glib;
with Gtk; use Gtk;
with Gdk.Types; use Gdk.Types;
with Gtk.Widget; use Gtk.Widget;
with Gtk.Enums; use Gtk.Enums;
with Gtkada.Handlers; use Gtkada.Handlers;
with Callbacks_Dictionary; use Callbacks_Dictionary;
with Dictionary_Intl; use Dictionary_Intl;
with Proof_Reading_Pkg.Callbacks; use Proof_Reading_Pkg.Callbacks;

with Ada.Command_Line;

package body Proof_Reading_Pkg is

procedure Gtk_New (Proof_Reading : out Proof_Reading_Access) is
begin
   Proof_Reading := new Proof_Reading_Record;
   Proof_Reading_Pkg.Initialize (Proof_Reading);
end Gtk_New;

procedure Initialize (Proof_Reading : access Proof_Reading_Record'Class) is
   pragma Suppress (All_Checks);
   Pixmaps_Dir : constant String := "pixmaps/";
   Vbox2_Group : Widget_SList.GSList;

begin
   Gtk.Window.Initialize (Proof_Reading, Window_Toplevel);
   Set_Title (Proof_Reading, "Proof-reading """ & Ada.Command_Line.Argument (1) & """");
   Set_Position (Proof_Reading, Win_Pos_None);
   Set_Modal (Proof_Reading, False);

   Gtk_New_Vbox (Proof_Reading.Vbox1, False, 0);
   Add (Proof_Reading, Proof_Reading.Vbox1);

   Gtk_New (Proof_Reading.Notebook1);
   Set_Scrollable (Proof_Reading.Notebook1, False);
   Set_Show_Border (Proof_Reading.Notebook1, True);
   Set_Show_Tabs (Proof_Reading.Notebook1, True);
   Set_Tab_Pos (Proof_Reading.Notebook1, Pos_Top);
   Pack_Start
     (Proof_Reading.Vbox1,
      Proof_Reading.Notebook1,
      Expand  => True,
      Fill    => True,
      Padding => 0);

   Gtk_New_Vbox (Proof_Reading.Vbox2, False, 0);
   Append_Page (Proof_Reading.Notebook1, Proof_Reading.Vbox2);
   Set_Tab_Label_Packing (Proof_Reading.Notebook1, Proof_Reading.Vbox2, False, True, Pack_Start);

   Gtk_New_Hbox (Proof_Reading.Hbox1, False, 0);
   Pack_Start
     (Proof_Reading.Vbox2,
      Proof_Reading.Hbox1,
      Expand  => True,
      Fill    => True,
      Padding => 0);

   Gtk_New (Proof_Reading.Label3, -("Word:"));
   Set_Alignment (Proof_Reading.Label3, 0.5, 0.5);
   Set_Padding (Proof_Reading.Label3, 0, 0);
   Set_Justify (Proof_Reading.Label3, Justify_Left);
   Set_Line_Wrap (Proof_Reading.Label3, False);
   Set_Selectable (Proof_Reading.Label3, False);
   Set_Use_Markup (Proof_Reading.Label3, False);
   Set_Use_Underline (Proof_Reading.Label3, False);
   Pack_Start
     (Proof_Reading.Hbox1,
      Proof_Reading.Label3,
      Expand  => False,
      Fill    => False,
      Padding => 0);

   Gtk_New (Proof_Reading.Word);
   Set_Editable (Proof_Reading.Word, False);
   Set_Max_Length (Proof_Reading.Word, 0);
   Set_Text (Proof_Reading.Word, Ada.Command_Line.Argument (1));
   Set_Visibility (Proof_Reading.Word, True);
   Set_Invisible_Char (Proof_Reading.Word, UTF8_Get_Char ("*"));
   Pack_Start
     (Proof_Reading.Hbox1,
      Proof_Reading.Word,
      Expand  => True,
      Fill    => True,
      Padding => 0);

   Gtk_New (Proof_Reading.Right, null, -("_Right"));
   Set_Relief (Proof_Reading.Right, Relief_Normal);
   Set_Active (Proof_Reading.Right, False);
   Set_Inconsistent (Proof_Reading.Right, False);
   Set_Relief (Proof_Reading.Right, Relief_Normal);
   Set_Use_Underline (Proof_Reading.Right, True);
   Pack_Start
     (Proof_Reading.Vbox2,
      Proof_Reading.Right,
      Expand  => False,
      Fill    => False,
      Padding => 0);
   Radio_Button_Callback.Connect
     (Proof_Reading.Right, "toggled",
      Radio_Button_Callback.To_Marshaller (On_Right_Toggled'Access), False);

   Gtk_New (Proof_Reading.Dunno, Proof_Reading.Right, -("_Dunno"));
   Set_Relief (Proof_Reading.Dunno, Relief_Normal);
   Set_Active (Proof_Reading.Dunno, True);
   Set_Inconsistent (Proof_Reading.Dunno, False);
   Set_Relief (Proof_Reading.Dunno, Relief_Normal);
   Set_Use_Underline (Proof_Reading.Dunno, True);
   Pack_Start
     (Proof_Reading.Vbox2,
      Proof_Reading.Dunno,
      Expand  => False,
      Fill    => False,
      Padding => 0);
   Radio_Button_Callback.Connect
     (Proof_Reading.Dunno, "toggled",
      Radio_Button_Callback.To_Marshaller (On_Dunno_Toggled'Access), False);

   Gtk_New (Proof_Reading.Wrong, Proof_Reading.Right, -("_Wrong"));
   Set_Relief (Proof_Reading.Wrong, Relief_Normal);
   Set_Active (Proof_Reading.Wrong, False);
   Set_Inconsistent (Proof_Reading.Wrong, False);
   Set_Relief (Proof_Reading.Wrong, Relief_Normal);
   Set_Use_Underline (Proof_Reading.Wrong, True);
   Pack_Start
     (Proof_Reading.Vbox2,
      Proof_Reading.Wrong,
      Expand  => False,
      Fill    => False,
      Padding => 0);
   Radio_Button_Callback.Connect
     (Proof_Reading.Wrong, "toggled",
      Radio_Button_Callback.To_Marshaller (On_Wrong_Toggled'Access), False);

   Gtk_New (Proof_Reading.Label1, -("Spelling"));
   Set_Alignment (Proof_Reading.Label1, 0.5, 0.5);
   Set_Padding (Proof_Reading.Label1, 0, 0);
   Set_Justify (Proof_Reading.Label1, Justify_Left);
   Set_Line_Wrap (Proof_Reading.Label1, False);
   Set_Selectable (Proof_Reading.Label1, False);
   Set_Use_Markup (Proof_Reading.Label1, False);
   Set_Use_Underline (Proof_Reading.Label1, False);
   Set_Tab (Proof_Reading.Notebook1, 0, Proof_Reading.Label1);

   Gtk_New_Hbox (Proof_Reading.Hbox2, False, 0);
   Append_Page (Proof_Reading.Notebook1, Proof_Reading.Hbox2);
   Set_Tab_Label_Packing (Proof_Reading.Notebook1, Proof_Reading.Hbox2, False, True, Pack_Start);

   Gtk_New (Proof_Reading.Label5, -("Correction:"));
   Set_Alignment (Proof_Reading.Label5, 0.5, 0.5);
   Set_Padding (Proof_Reading.Label5, 0, 0);
   Set_Justify (Proof_Reading.Label5, Justify_Left);
   Set_Line_Wrap (Proof_Reading.Label5, False);
   Set_Selectable (Proof_Reading.Label5, False);
   Set_Use_Markup (Proof_Reading.Label5, False);
   Set_Use_Underline (Proof_Reading.Label5, False);
   Pack_Start
     (Proof_Reading.Hbox2,
      Proof_Reading.Label5,
      Expand  => False,
      Fill    => False,
      Padding => 0);

   Gtk_New (Proof_Reading.Correction);
   Set_Editable (Proof_Reading.Correction, True);
   Set_Max_Length (Proof_Reading.Correction, 0);
   Set_Text (Proof_Reading.Correction, -(""));
   Set_Visibility (Proof_Reading.Correction, True);
   Set_Invisible_Char (Proof_Reading.Correction, UTF8_Get_Char ("*"));
   Pack_Start
     (Proof_Reading.Hbox2,
      Proof_Reading.Correction,
      Expand  => True,
      Fill    => True,
      Padding => 0);

   Gtk_New (Proof_Reading.Label4, -("Correction"));
   Set_Alignment (Proof_Reading.Label4, 0.5, 0.5);
   Set_Padding (Proof_Reading.Label4, 0, 0);
   Set_Justify (Proof_Reading.Label4, Justify_Left);
   Set_Line_Wrap (Proof_Reading.Label4, False);
   Set_Selectable (Proof_Reading.Label4, False);
   Set_Use_Markup (Proof_Reading.Label4, False);
   Set_Use_Underline (Proof_Reading.Label4, False);
   Set_Tab (Proof_Reading.Notebook1, 1, Proof_Reading.Label4);

   Gtk_New (Proof_Reading.Hbuttonbox1);
   Set_Spacing (Proof_Reading.Hbuttonbox1, 0);
   Set_Layout (Proof_Reading.Hbuttonbox1, Buttonbox_Default_Style);
   Pack_Start
     (Proof_Reading.Vbox1,
      Proof_Reading.Hbuttonbox1,
      Expand  => True,
      Fill    => True,
      Padding => 0);

   Gtk_New_From_Stock (Proof_Reading.Button1, "gtk-cancel");
   Set_Relief (Proof_Reading.Button1, Relief_Normal);
   Set_Flags (Proof_Reading.Button1, Can_Default);
   Button_Callback.Connect
     (Proof_Reading.Button1, "clicked",
      Button_Callback.To_Marshaller (Quit'Access), False);
   Pack_Start (Proof_Reading.Hbuttonbox1, Proof_Reading.Button1);

   Gtk_New_From_Stock (Proof_Reading.Button2, "gtk-ok");
   Set_Relief (Proof_Reading.Button2, Relief_Normal);
   Set_Flags (Proof_Reading.Button2, Can_Default);
   Button_Callback.Connect
     (Proof_Reading.Button2, "clicked",
      Button_Callback.To_Marshaller (Done'Access), False);
   Pack_Start (Proof_Reading.Hbuttonbox1, Proof_Reading.Button2);

   Gtk_New_From_Stock (Proof_Reading.Button3, "gtk-go-forward");
   Set_Relief (Proof_Reading.Button3, Relief_Normal);
   Set_Flags (Proof_Reading.Button3, Can_Default);
   Button_Callback.Connect
     (Proof_Reading.Button3, "clicked",
      Button_Callback.To_Marshaller (Forward'Access), False);
   Pack_Start (Proof_Reading.Hbuttonbox1, Proof_Reading.Button3);

end Initialize;

end Proof_Reading_Pkg;
